#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from __future__ import annotations

from typing import Optional, Union
from dataclasses import dataclass
from ..config import Object
import rubio.core


@dataclass
class ButtonLocation(Object):
    """
    **Represents a location picker button.**
        `from rubio.core.types import ButtonLocation`

    Attributes:
        default_pointer_location (`Optional[rubio.core.types.Location]`):
            Default pointer location.

        default_map_location (`Optional[rubio.core.types.Location]`):
            Default map location.

        type (`Optional[Union[str, rubio.core.enums.ButtonLocationType]]`):
            Type of location picker.

        title (`Optional[str]`):
            Title of the location picker.

        location_image_url (`Optional[str]`):
            Optional image URL for the location.
    """
    default_pointer_location: Optional[rubio.core.types.Location] = None
    default_map_location: Optional[rubio.core.types.Location] = None
    type: Optional[Union[str, rubio.core.enums.ButtonLocationType]] = None
    title: Optional[str] = None
    location_image_url: Optional[str] = None