#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class ChatActionType(Enum):
    """
    **Represents the types of actions a user can perform in a chat.**
        `from rubio.core.enums import ChatActionType`

    Attributes:
        TYPING (str): Indicates the user is typing a message.
        UPLOADING (str): Indicates the user is uploading a file.
        RECORDING (str): Indicates the user is recording a voice message.
    """

    TYPING = "Typing"
    UPLOADING = "Uploading"
    RECORDING = "Recording"