#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from __future__ import annotations

from dataclasses import dataclass, field
from ..config import Object
import rubio.core


@dataclass
class KeypadRow(Object):
    """
    **Represents a single row of buttons in a chat keypad.**
        `from rubio.core.types import KeypadRow`

    Attributes:
        buttons (`list[rubio.core.types.Button]`):
            A list of Button objects in this row.
    """
    buttons: list[rubio.core.types.Button] = field(default_factory=list)