#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class MetadataType(Enum):
    BOLD = "Bold"
    MONO = "Mono"
    LINK = "Link"
    QUOTE = "Quote"
    ITALIC = "Italic"
    STRIKE = "Strike"
    SPOILER = "Spoiler"
    UNDERLINE = "Underline"
    MENTION_TETX = "MentionText"