#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from dataclasses import dataclass
from .config import Object


@dataclass
class Location(Object):
    """
    **Represents a geographical location.**
        `from rubio.core.types import Location`

    Attributes:
        longitude (`str`):
            Longitude of the location.

        latitude (`str`):
            Latitude of the location.
    """
    longitude: str
    latitude: str