#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from __future__ import annotations

from typing import Optional
from dataclasses import dataclass
from .config import Object
import rubio.core


@dataclass
class Poll(Object):
    """
    **Represents a poll in Rubigram.**
        `from rubio.core.types import Poll`

    Attributes:
        question (`Optional[str]`):
            The poll question text.

        options (`Optional[list[str]]`):
            List of possible answer options.

        poll_status (`Optional[rubio.core.types.PollStatus]`):
            Status information of the poll.
    """
    question: Optional[str] = None
    options: Optional[list[str]] = None
    poll_status: Optional[rubio.core.types.PollStatus] = None