#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class ForwardedFromType(Enum):
    """
    **Represents the original sender of a forwarded message.**
        `from rubio.core.enums import ForwardedFromType`

    Attributes:
        USER (str): The message was forwarded from a user.
        BOT (str): The message was forwarded from a bot.
        CHANNEL (str): The message was forwarded from a channel.
    """

    USER = "User"
    BOT = "Bot"
    CHANNEL = "Channel"
