#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .get_chat import GetChat
from .get_chat_member import GetChatMember
from .ban_chat_member import BanChatMember
from .unban_chat_member import UnbanChatMember


class Chats(
    GetChat,
    GetChatMember,
    BanChatMember,
    UnbanChatMember
):
    pass