#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .request import Request
from .upload_file import UploadFile
from .get_file_name import GetFileName
from .download_file import DownloadFile


class Network(
    Request,
    UploadFile,
    GetFileName,
    DownloadFile
):
    pass