#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from ..enum import Enum


class ButtonLocationType(Enum):
    """
    **Represents the types of location buttons.**
        `from rubio.core.enums import ButtonLocationType`

    Attributes:
        PICKER (str): A button to pick a location.
        VIEW (str): A button to view a location.
    """

    PICKER = "Picker"
    VIEW = "View"