#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from __future__ import annotations

from typing import Optional
from dataclasses import dataclass
from .config import Object
import rubio.core



@dataclass
class Sticker(Object):
    """
    **Represents a sticker in Rubigram.**
        `from rubio.core.types import Sticker`

    Attributes:
        sticker_id (`Optional[str]`):
            Unique identifier for the sticker.

        file (`Optional[rubio.core.types.File]`):
            File object representing the sticker image.

        emoji_character (`Optional[str]`):
            Associated emoji character for the sticker.
    """
    sticker_id: Optional[str] = None
    file: Optional[rubio.core.types.File] = None
    emoji_character: Optional[str] = None