#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from . import errors, enums, types, filters
from .state import State, Storage
from .handlers import Handler
from .client import Client
from .server import Server
from .rubino import Rubino


class StopPropagation(StopAsyncIteration):
    pass


class ContinuePropagation(StopAsyncIteration):
    pass


__version__ = "1.7.21"
__author__ = "PyRubio"
__github__ = "https://github.ocm/RubioTeam/rubio.core"
__message__ = "Welcome to Rubigram Client\nYou are using version %s", __version__