#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class PollStatusType(Enum):
    """
    **Represents the status of a poll.**
        `from rubio.core.enums import PollStatusType`

    Attributes:
        OPEN (str): The poll is currently open and accepting votes.
        CLOSED (str): The poll is closed and no longer accepting votes.
    """

    OPEN = "Open"
    CLOSED = "Closed"