#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class FileType(Enum):
    """
    **Represents the different types of files that can be sent or received.**
        `from rubio.core.enums import FileType`

    Attributes:
        FILE (str): A generic file.
        IMAGE (str): An image file.
        VIDEO (str): A video file.
        GIF (str): A GIF file.
        MUSIC (str): An audio/music file.
        VOICE (str): A voice message file.
    """

    FILE = "File"
    IMAGE = "Image"
    VIDEO = "Video"
    GIF = "Gif"
    MUSIC = "Music"
    VOICE = "Voice"