#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from ..enum import Enum


class ButtonSelectionGetType(Enum):
    """
    **Represents the methods available to retrieve selection button data.**
        `from rubio.core.enums import ButtonSelectionGetType`

    Attributes:
        LOCAL (str): Retrieve data locally.
        API (str): Retrieve data via API.
    """

    LOCAL = "Local"
    API = "Api"