#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from typing import Optional
from dataclasses import dataclass
from ..config import Object


@dataclass
class ButtonStringPicker(Object):
    """
    **Represents a string picker button.**
        `from rubio.core.types import ButtonStringPicker`

    Attributes:
        items (`Optional[list[str]]`):
            List of string options to select from.

        default_value (`Optional[str]`):
            Default selected string.

        title (`Optional[str]`):
            Title of the string picker.
    """
    items: Optional[list[str]] = None
    default_value: Optional[str] = None
    title: Optional[str] = None