#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class PaymentStatusType(Enum):
    """
    **Represents the payment status of an item or transaction.**
        `from rubio.core.enums import PaymentStatusType`

    Attributes:
        PAID (str): The payment has been completed.
        NOT_PAID (str): The payment has not been completed.
    """

    PAID = "Paid"
    NOT_PAID = "NotPaid"