#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from ..enum import Enum


class ButtonTextboxTypeKeypad(Enum):
    """
    **Represents the keypad types available for textbox buttons.**
        `from rubio.core.enums import ButtonTextboxTypeKeypad`

    Attributes:
        STRING (str): Textbox accepts string input.
        NUMBER (str): Textbox accepts numeric input.
    """

    STRING = "String"
    NUMBER = "Number"