from setuptools import setup, find_packages
setup(
    name="Rubio",
    version="7.0.0",
    author="Rubio Team",
    description="Professional Rubika Bot API V3 Framework @RubioLib",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=["httpx", "aiohttp", "aiofiles"],
)
