#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from ..enum import Enum


class ButtonCalendarType(Enum):
    """
    **Represents the calendar types available for calendar buttons.**
        `from rubio.core.enums import ButtonCalendarType`

    Attributes:
        DATE_PERSIAN (str): Persian (Jalali) calendar type.
        DATE_GREGORIAN (str): Gregorian calendar type.
    """

    DATE_PERSIAN = "DatePersian"
    DATE_GREGORIAN = "DateGregorian"