#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class ParseMode(Enum):
    """
    **Represents the text parsing modes for messages.**
        `from rubio.core.enums import ParseMode`

    Attributes:
        MARKDOWN (str): Parses the message as Markdown.
        HTML (str): Parses the message as HTML.
    """

    MARKDOWN = "markdown"
    HTML = "html"