#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from ..enum import Enum


class ButtonSelectionSearchType(Enum):
    """
    **Represents the search modes available for selection buttons.**
        `from rubio.core.enums import ButtonSelectionSearchType`

    Attributes:
        LOCAL (str): Search is performed locally.
        API (str): Search is performed via API.
    """

    LOCAL = "Local"
    API = "Api"