#  Rubio - Rubika API library for python
#  Copyright (C) 2025-present Rubio <https://github.com/RubioTeam>
#  Github - https://github.com/RubioTeam/rubio.core


from .enum import Enum


class LiveLocationStatus(Enum):
    """
    **Represents the status of a live location.**
        `from rubio.core.enums import LiveLocationStatus`

    Attributes:
        STOPPED (str): The live location has been stopped.
        LIVE (str): The live location is currently active.
    """

    STOPPED = "Stopped"
    LIVE = "Live"